Crate ohos_web_sys

Crate ohos_web_sys 

Structs

ArkWeb_AnyNativeAPI
@brief Defines the native API type of any size.
ArkWeb_ComponentAPI
@brief Defines the component API for native ArkWeb.
ArkWeb_ControllerAPI
@brief Defines the controller API for native ArkWeb. Before invoking an API, you are advised to use ARKWEB_MEMBER_MISSING to check whether the function structure has a corresponding function pointer to avoid crash caused by mismatch between the SDK and the device ROM. Use OH_ArkWeb_GetNativeAPI in the UI thread to obtain the Controller-related interface cluster.
ArkWeb_CookieManagerAPI
@brief Defines the native CookieManager API for ArkWeb. Before invoking an API, you are advised to use ARKWEB_MEMBER_MISSING to check whether the function structure has a corresponding function pointer to avoid crash caused by mismatch between the SDK and the device ROM. Use OH_ArkWeb_GetNativeAPI in the UI thread to obtain the CookieManager-related interface cluster.
ArkWeb_HttpBodyStream_
ArkWeb_JavaScriptBridgeData
@brief Defines the javascript bridge data type.
ArkWeb_JavaScriptObject
@brief Defines the javascript object.
ArkWeb_JavaScriptValue
ArkWeb_ProxyMethod
@brief Defines the javascript proxy registered method object.
ArkWeb_ProxyObject
@brief Defines the javascript proxy registered object.
ArkWeb_RequestHeaderList_
ArkWeb_ResourceHandler_
ArkWeb_ResourceRequest_
ArkWeb_Response_
ArkWeb_SchemeHandler_
ArkWeb_WebMessage
ArkWeb_WebMessageAPI
@brief Defines the web message data API for native ArkWeb. Before invoking an API, you are advised to use ARKWEB_MEMBER_MISSING to check whether the function structure has a corresponding function pointer to avoid crash caused by mismatch between the SDK and the device ROM. Use OH_ArkWeb_GetNativeAPI in the UI thread to obtain the WebMessage-related interface cluster.
ArkWeb_WebMessagePort
ArkWeb_WebMessagePortAPI
@brief Defines the web message API for native ArkWeb. Before invoking an API, you are advised to use ARKWEB_MEMBER_MISSING to check whether the function structure has a corresponding function pointer to avoid crash caused by mismatch between the SDK and the device ROM. Use OH_ArkWeb_GetNativeAPI in the UI thread to obtain the WebMessagePort-related interface cluster.

Constants

ArkWeb_CustomSchemeOption_ARKWEB_SCHEME_OPTION_CODE_CACHE_ENABLED
If ARKWEB_SCHEME_OPTION_CODE_CACHE_ENABLED is set, then the js of this scheme can generate code cache.
ArkWeb_CustomSchemeOption_ARKWEB_SCHEME_OPTION_CORS_ENABLED
If ARKWEB_SCHEME_OPTION_CORS_ENABLED is set, then the scheme can be sent CORS requests. In most cases this value should be set when ARKWEB_SCHEME_OPTION_STANDARD is set.
ArkWeb_CustomSchemeOption_ARKWEB_SCHEME_OPTION_CSP_BYPASSING
If ARKWEB_SCHEME_OPTION_CSP_BYPASSING is set, then this scheme can bypass Content Security Policy (CSP) checks. In most cases, this value should not be set when ARKWEB_SCHEME_OPTION_STANDARD is set.
ArkWeb_CustomSchemeOption_ARKWEB_SCHEME_OPTION_DISPLAY_ISOLATED
If ARKWEB_SCHEME_OPTION_DISPLAY_ISOLATED is set, then the scheme can only be displayed from other content hosted using the same scheme.
ArkWeb_CustomSchemeOption_ARKWEB_SCHEME_OPTION_FETCH_ENABLED
If ARKWEB_SCHEME_OPTION_FETCH_ENABLED is set, then this scheme can perform FETCH API requests.
ArkWeb_CustomSchemeOption_ARKWEB_SCHEME_OPTION_LOCAL
If ARKWEB_SCHEME_OPTION_LOCAL is set, the same security rules as those applied to the “file” URL will be used to handle the scheme.
ArkWeb_CustomSchemeOption_ARKWEB_SCHEME_OPTION_SECURE
If ARKWEB_SCHEME_OPTION_SECURE is set, the same security rules as those applied to the “https” URL will be used to handle the scheme.
ArkWeb_CustomSchemeOption_ARKWEB_SCHEME_OPTION_STANDARD
If ARKWEB_SCHEME_OPTION_STANDARD is set, the scheme will be handled as a standard scheme. The standard schemes need to comply with the URL normalization and parsing rules defined in Section 3.1 of RFC 1738, which can be found in the http://www.ietf.org/rfc/rfc1738.txt.
ArkWeb_CustomSchemeOption_OH_ARKWEB_SCHEME_OPTION_NONE
ArkWeb_ErrorCode_ARKWEB_ERROR_UNKNOWN
@error Unknown error.
ArkWeb_ErrorCode_ARKWEB_INIT_ERROR
@error Init error.
ArkWeb_ErrorCode_ARKWEB_INVALID_COOKIE_VALUE
@error Invalid cookie value.
ArkWeb_ErrorCode_ARKWEB_INVALID_PARAM
@error Invalid param.
ArkWeb_ErrorCode_ARKWEB_INVALID_URL
@error Invalid url.
ArkWeb_ErrorCode_ARKWEB_LIBRARY_OPEN_FAILURE
ArkWeb_ErrorCode_ARKWEB_LIBRARY_SYMBOL_NOT_FOUND
ArkWeb_ErrorCode_ARKWEB_SCHEME_REGISTER_FAILED
@error Register custom schemes should be called before create any ArkWeb.
ArkWeb_ErrorCode_ARKWEB_SUCCESS
@error Success.
ArkWeb_NativeAPIVariantKind_ARKWEB_NATIVE_COMPONENT
API type related to ArkWeb component.
ArkWeb_NativeAPIVariantKind_ARKWEB_NATIVE_CONTROLLER
API type related to ArkWeb controller.
ArkWeb_NativeAPIVariantKind_ARKWEB_NATIVE_COOKIE_MANAGER
API type related to ArkWeb cookie manager.
ArkWeb_NativeAPIVariantKind_ARKWEB_NATIVE_WEB_MESSAGE
API type related to ArkWeb WebMessage.
ArkWeb_NativeAPIVariantKind_ARKWEB_NATIVE_WEB_MESSAGE_PORT
API type related to ArkWeb WebMessagePort.
ArkWeb_NetError_ARKWEB_ERR_ABORTED
@error An operation was aborted.
ArkWeb_NetError_ARKWEB_ERR_ACCESS_DENIED
@error Permission to access a resource, other than the network, was denied.
ArkWeb_NetError_ARKWEB_ERR_ADDRESS_INVALID
@error The IP address or port number is invalid (e.g., cannot connect to the IP address 0 or the port 0).
ArkWeb_NetError_ARKWEB_ERR_ADDRESS_IN_USE
@error Returned when attempting to bind an address that is already in use.
ArkWeb_NetError_ARKWEB_ERR_ADDRESS_UNREACHABLE
@error The IP address is unreachable. This usually means that there is no route to the specified host or network.
ArkWeb_NetError_ARKWEB_ERR_ADD_USER_CERT_FAILED
@error An error adding a certificate to the OS certificate database.
ArkWeb_NetError_ARKWEB_ERR_ALPN_NEGOTIATION_FAILED
@error The request to negotiate an alternate protocol failed.
ArkWeb_NetError_ARKWEB_ERR_BAD_SSL_CLIENT_AUTH_CERT
@error The SSL handshake failed because of a bad or missing client certificate.
ArkWeb_NetError_ARKWEB_ERR_BLOCKED_BY_ADMINISTRATOR
@error The request was blocked by the URL block list configured by the domain administrator.
ArkWeb_NetError_ARKWEB_ERR_BLOCKED_BY_CLIENT
@error The client chose to block the request.
ArkWeb_NetError_ARKWEB_ERR_BLOCKED_BY_CSP
@error The request was blocked by a Content Security Policy.
ArkWeb_NetError_ARKWEB_ERR_BLOCKED_BY_ORB
@error The request was blocked by CORB or ORB.
ArkWeb_NetError_ARKWEB_ERR_BLOCKED_BY_RESPONSE
@error The request failed because the response was delivered along with requirements which are not met (‘X-Frame-Options’ and ‘Content-Security-Policy’ ancestor checks and ‘Cross-Origin-Resource-Policy’ for instance).
ArkWeb_NetError_ARKWEB_ERR_CACHED_IP_ADDRESS_SPACE_BLOCKED_BY_LOCAL_NETWORK_ACCESS_POLICY
@error The IP address space of the cached remote endpoint is blocked by local network access check.
ArkWeb_NetError_ARKWEB_ERR_CACHE_AUTH_FAILURE_AFTER_READ
@error Received a challenge after the transaction has read some data, and the credentials aren’t available.
ArkWeb_NetError_ARKWEB_ERR_CACHE_CHECKSUM_MISMATCH
@error The cache found an entry with an invalid checksum.
ArkWeb_NetError_ARKWEB_ERR_CACHE_CHECKSUM_READ_FAILURE
@error The cache was unable to read a checksum record on an entry.
ArkWeb_NetError_ARKWEB_ERR_CACHE_CREATE_FAILURE
@error The disk cache is unable to create this entry.
ArkWeb_NetError_ARKWEB_ERR_CACHE_DOOM_FAILURE
@error The disk cache is unable to doom this entry.
ArkWeb_NetError_ARKWEB_ERR_CACHE_ENTRY_NOT_SUITABLE
@error Internal not-quite error code for the HTTP cache.
ArkWeb_NetError_ARKWEB_ERR_CACHE_LOCK_TIMEOUT
@error Internal error code for the HTTP cache.
ArkWeb_NetError_ARKWEB_ERR_CACHE_MISS
@error The cache does not have the requested entry.
ArkWeb_NetError_ARKWEB_ERR_CACHE_OPEN_FAILURE
@error The disk cache is unable to open this entry.
ArkWeb_NetError_ARKWEB_ERR_CACHE_OPEN_OR_CREATE_FAILURE
@error The disk cache is unable to open or create this entry.
ArkWeb_NetError_ARKWEB_ERR_CACHE_OPERATION_UNSUPPORTED
@error The operation is not supported for this entry.
ArkWeb_NetError_ARKWEB_ERR_CACHE_RACE
@error Multiple transactions are racing to create disk cache entries.
ArkWeb_NetError_ARKWEB_ERR_CACHE_READ_FAILURE
@error Unable to read from the disk cache.
ArkWeb_NetError_ARKWEB_ERR_CACHE_WRITE_FAILURE
@error Unable to write to the disk cache.
ArkWeb_NetError_ARKWEB_ERR_CERTIFICATE_TRANSPARENCY_REQUIRED
@error Certificate Transparency was required for this connection, but the server did not provide CT information that complied with the policy.
ArkWeb_NetError_ARKWEB_ERR_CERT_AUTHORITY_INVALID
@error The server responded with a certificate that is signed by an authority we don’t trust. The could mean: 1. An attacker has substituted the real certificate for a cert that contains their public key and is signed by their cousin. 2. The server operator has a legitimate certificate from a CA we don’t know about, but should trust. 3. The server is presenting a self-signed certificate, providing no defense against active attackers (but foiling passive attackers).
ArkWeb_NetError_ARKWEB_ERR_CERT_COMMON_NAME_INVALID
@error The server responded with a certificate whose common name did not match the host name. This could mean: 1. An attacker has redirected our traffic to their server and is presenting a certificate for which they know the private key. 2. The server is misconfigured and responding with the wrong cert. 3. The user is on a wireless network and is being redirected to the network’s login page. 4. The OS has used a DNS search suffix and the server doesn’t have a certificate for the abbreviated name in the address bar.
ArkWeb_NetError_ARKWEB_ERR_CERT_CONTAINS_ERRORS
@error The server responded with a certificate that contains errors. This error is not recoverable. MSDN describes this error as follows: “The SSL certificate contains errors.” NOTE: It’s unclear how this differs from ERR_CERT_INVALID. For consistency, use that code instead of this one from now on.
ArkWeb_NetError_ARKWEB_ERR_CERT_DATABASE_CHANGED
@error The certificate database changed in some way.
ArkWeb_NetError_ARKWEB_ERR_CERT_DATE_INVALID
@error The server responded with a certificate that, by our clock, appears to either not yet be valid or to have expired. This could mean: 1. An attacker is presenting an old certificate for which they have managed to obtain the private key. 2. The server is misconfigured and is not presenting a valid cert. 3. Our clock is wrong.
ArkWeb_NetError_ARKWEB_ERR_CERT_END
@error The value immediately past the last certificate error code.
ArkWeb_NetError_ARKWEB_ERR_CERT_INVALID
@error The server responded with a certificate that is invalid. This error is not recoverable. MSDN describes this error as follows: “The SSL certificate is invalid.”
ArkWeb_NetError_ARKWEB_ERR_CERT_KNOWN_INTERCEPTION_BLOCKED
@error The certificate is known to be used for interception by an entity other the device owner.
ArkWeb_NetError_ARKWEB_ERR_CERT_NAME_CONSTRAINT_VIOLATION
@error The certificate claimed DNS names that are in violation of name constraints.
ArkWeb_NetError_ARKWEB_ERR_CERT_NON_UNIQUE_NAME
@error The host name specified in the certificate is not unique.
ArkWeb_NetError_ARKWEB_ERR_CERT_NO_REVOCATION_MECHANISM
@error The certificate has no mechanism for determining if it is revoked. In effect, this certificate cannot be revoked.
ArkWeb_NetError_ARKWEB_ERR_CERT_REVOKED
@error The server responded with a certificate has been revoked. We have the capability to ignore this error, but it is probably not the thing to do.
ArkWeb_NetError_ARKWEB_ERR_CERT_SYMANTEC_LEGACY
@error The certificate chained to a legacy Symantec root that is no longer trusted.
ArkWeb_NetError_ARKWEB_ERR_CERT_UNABLE_TO_CHECK_REVOCATION
@error Revocation information for the security certificate for this site is not available. This could mean: 1. An attacker has compromised the private key in the certificate and is blocking our attempt to find out that the cert was revoked. 2. The certificate is unrevoked, but the revocation server is busy or unavailable.
ArkWeb_NetError_ARKWEB_ERR_CERT_VALIDITY_TOO_LONG
@error The certificate’s validity period is too long.
ArkWeb_NetError_ARKWEB_ERR_CERT_VERIFIER_CHANGED
@error The certificate verifier configuration changed in some way.
ArkWeb_NetError_ARKWEB_ERR_CERT_WEAK_KEY
@error The server responded with a certificate that contains a weak key (e.g. a too-small RSA key).
ArkWeb_NetError_ARKWEB_ERR_CERT_WEAK_SIGNATURE_ALGORITHM
@error The server responded with a certificate that is signed using a weak signature algorithm.
ArkWeb_NetError_ARKWEB_ERR_CLEARTEXT_NOT_PERMITTED
@error The request was blocked by system policy disallowing some or all cleartext requests.
ArkWeb_NetError_ARKWEB_ERR_CLIENT_AUTH_CERT_TYPE_UNSUPPORTED
@error Server request for client certificate did not contain any types we support.
ArkWeb_NetError_ARKWEB_ERR_CONNECTION_ABORTED
@error A connection timed out as a result of not receiving an ACK for data sent. This can include a FIN packet that did not get ACK’d.
ArkWeb_NetError_ARKWEB_ERR_CONNECTION_CLOSED
@error A connection was closed (corresponding to a TCP FIN).
ArkWeb_NetError_ARKWEB_ERR_CONNECTION_FAILED
@error A connection attempt failed.
ArkWeb_NetError_ARKWEB_ERR_CONNECTION_REFUSED
@error A connection attempt was refused.
ArkWeb_NetError_ARKWEB_ERR_CONNECTION_RESET
@error A connection was reset (corresponding to a TCP RST).
ArkWeb_NetError_ARKWEB_ERR_CONNECTION_TIMED_OUT
@error A connection attempt timed out.
ArkWeb_NetError_ARKWEB_ERR_CONTENT_DECODING_FAILED
@error Content decoding of the response body failed.
ArkWeb_NetError_ARKWEB_ERR_CONTENT_DECODING_INIT_FAILED
@error Initializing content decoding failed.
ArkWeb_NetError_ARKWEB_ERR_CONTENT_LENGTH_MISMATCH
@error The HTTP response body transferred fewer bytes than were advertised by the Content-Length header when the connection is closed.
ArkWeb_NetError_ARKWEB_ERR_CONTEXT_SHUT_DOWN
@error The request failed because the URLRequestContext is shutting down, or has been shut down.
ArkWeb_NetError_ARKWEB_ERR_CT_CONSISTENCY_PROOF_PARSING_FAILED
@error Certificate Transparency: Failed to parse the received consistency proof.
ArkWeb_NetError_ARKWEB_ERR_CT_STH_INCOMPLETE
@error Certificate Transparency: Received a signed tree head whose JSON parsing was OK but was missing some of the fields.
ArkWeb_NetError_ARKWEB_ERR_CT_STH_PARSING_FAILED
@error Certificate Transparency: Received a signed tree head that failed to parse.
ArkWeb_NetError_ARKWEB_ERR_DISALLOWED_URL_SCHEME
@error The scheme of the URL is disallowed.
ArkWeb_NetError_ARKWEB_ERR_DNS_CACHE_MISS
@error The entry was not found in cache or other local sources, for lookups where only local sources were queried.
ArkWeb_NetError_ARKWEB_ERR_DNS_MALFORMED_RESPONSE
@error DNS resolver received a malformed response.
ArkWeb_NetError_ARKWEB_ERR_DNS_NAME_HTTPS_ONLY
@error DNS identified the request as disallowed for insecure connection (http/ws). Error should be handled as if an HTTP redirect was received to redirect to https or wss.
ArkWeb_NetError_ARKWEB_ERR_DNS_NO_MATCHING_SUPPORTED_ALPN
@error The hostname resolution of HTTPS record was expected to be resolved with alpn values of supported protocols, but did not.
ArkWeb_NetError_ARKWEB_ERR_DNS_REQUEST_CANCELED
@error All DNS requests associated with this job have been cancelled.
ArkWeb_NetError_ARKWEB_ERR_DNS_SEARCH_EMPTY
@error Suffix search list rules prevent resolution of the given host name.
ArkWeb_NetError_ARKWEB_ERR_DNS_SECURE_RESOLVER_HOSTNAME_RESOLUTION_FAILED
@error Failed to resolve the hostname of a DNS-over-HTTPS server.
ArkWeb_NetError_ARKWEB_ERR_DNS_SERVER_FAILED
@error DNS server failed. This error is returned for all of the following error conditions: 1 - Format error - The name server was unable to interpret the query. 2 - Server failure - The name server was unable to process this query due to a problem with the name server. 4 - Not Implemented - The name server does not support the requested kind of query. 5 - Refused - The name server refuses to perform the specified operation for policy reasons.
ArkWeb_NetError_ARKWEB_ERR_DNS_SERVER_REQUIRES_TCP
@error DNS server requires TCP.
ArkWeb_NetError_ARKWEB_ERR_DNS_SORT_ERROR
@error Failed to sort addresses according to RFC3484.
ArkWeb_NetError_ARKWEB_ERR_DNS_TIMED_OUT
@error DNS transaction timed out.
ArkWeb_NetError_ARKWEB_ERR_EARLY_DATA_REJECTED
@error TLS 1.3 early data was rejected by the server. This will be received before any data is returned from the socket. The request should be retried with early data disabled.
ArkWeb_NetError_ARKWEB_ERR_ECH_FALLBACK_CERTIFICATE_INVALID
@error ECH was enabled, the server was unable to decrypt the encrypted ClientHello, and additionally did not present a certificate valid for the public name.
ArkWeb_NetError_ARKWEB_ERR_ECH_NOT_NEGOTIATED
@error ECH was enabled, but the server was unable to decrypt the encrypted ClientHello.
ArkWeb_NetError_ARKWEB_ERR_EMPTY_RESPONSE
@error The server closed the connection without sending any data.
ArkWeb_NetError_ARKWEB_ERR_ENCODING_CONVERSION_FAILED
@error Converting the response to target encoding failed.
ArkWeb_NetError_ARKWEB_ERR_ENCODING_DETECTION_FAILED
@error Detecting the encoding of the response failed.
ArkWeb_NetError_ARKWEB_ERR_FAILED
@error A generic failure occurred.
ArkWeb_NetError_ARKWEB_ERR_FILE_EXISTS
@error The file already exists.
ArkWeb_NetError_ARKWEB_ERR_FILE_NOT_FOUND
@error The file or directory cannot be found.
ArkWeb_NetError_ARKWEB_ERR_FILE_NO_SPACE
@error Not enough room left on the disk.
ArkWeb_NetError_ARKWEB_ERR_FILE_PATH_TOO_LONG
@error The path or file name is too long.
ArkWeb_NetError_ARKWEB_ERR_FILE_TOO_LARGE
@error The file is too large.
ArkWeb_NetError_ARKWEB_ERR_FILE_VIRUS_INFECTED
@error The file has a virus.
ArkWeb_NetError_ARKWEB_ERR_FTP_BAD_COMMAND_SEQUENCE
@error Server rejected our command because we didn’t issue the commands in right order. FTP response code 503.
ArkWeb_NetError_ARKWEB_ERR_FTP_COMMAND_UNSUPPORTED
@error Server does not support the command we issued. FTP response codes 502, 504.
ArkWeb_NetError_ARKWEB_ERR_FTP_FAILED
@error A generic error for failed FTP control connection command. If possible, please use or add a more specific error code.
ArkWeb_NetError_ARKWEB_ERR_FTP_FILE_BUSY
@error The file is busy, or some other temporary error condition on opening the file. FTP response code 450.
ArkWeb_NetError_ARKWEB_ERR_FTP_SERVICE_UNAVAILABLE
@error The server cannot fulfill the request at this point. This is a temporary error. FTP response code 421.
ArkWeb_NetError_ARKWEB_ERR_FTP_SYNTAX_ERROR
@error Server rejected our command because of syntax errors. FTP response codes 500, 501.
ArkWeb_NetError_ARKWEB_ERR_FTP_TRANSFER_ABORTED
@error The server has aborted the transfer. FTP response code 426.
ArkWeb_NetError_ARKWEB_ERR_H2_OR_QUIC_REQUIRED
@error The request was blocked because of no H/2 or QUIC session.
ArkWeb_NetError_ARKWEB_ERR_HOST_RESOLVER_QUEUE_TOO_LARGE
@error There are too many pending DNS resolves, so a request in the queue was aborted.
ArkWeb_NetError_ARKWEB_ERR_HTTP2_CLAIMED_PUSHED_STREAM_RESET_BY_SERVER
@error A pushed stream was claimed and later reset by the server. When this happens, the request should be retried.
ArkWeb_NetError_ARKWEB_ERR_HTTP2_CLIENT_REFUSED_STREAM
@error Client is refusing an HTTP/2 stream.
ArkWeb_NetError_ARKWEB_ERR_HTTP2_COMPRESSION_ERROR
@error Decoding or encoding of compressed HTTP/2 headers failed.
ArkWeb_NetError_ARKWEB_ERR_HTTP2_FLOW_CONTROL_ERROR
@error The peer violated HTTP/2 flow control.
ArkWeb_NetError_ARKWEB_ERR_HTTP2_FRAME_SIZE_ERROR
@error The peer sent an improperly sized HTTP/2 frame.
ArkWeb_NetError_ARKWEB_ERR_HTTP2_INADEQUATE_TRANSPORT_SECURITY
@error Transport security is inadequate for the HTTP/2 version.
ArkWeb_NetError_ARKWEB_ERR_HTTP2_PING_FAILED
@error HTTP/2 server didn’t respond to the PING message.
ArkWeb_NetError_ARKWEB_ERR_HTTP2_PROTOCOL_ERROR
@error There is an HTTP/2 protocol error.
ArkWeb_NetError_ARKWEB_ERR_HTTP2_PUSHED_RESPONSE_DOES_NOT_MATCH
@error A pushed HTTP/2 stream was claimed by a request based on matching URL and request headers, but the pushed response headers do not match the request.
ArkWeb_NetError_ARKWEB_ERR_HTTP2_PUSHED_STREAM_NOT_AVAILABLE
@error The pushed stream claimed by the request is no longer available.
ArkWeb_NetError_ARKWEB_ERR_HTTP2_RST_STREAM_NO_ERROR_RECEIVED
@error Received HTTP/2 RST_STREAM frame with NO_ERROR error code. This error should be handled internally by HTTP/2 code, and should not make it above the SpdyStream layer.
ArkWeb_NetError_ARKWEB_ERR_HTTP2_SERVER_REFUSED_STREAM
@error HTTP/2 server refused the request without processing, and sent either a GOAWAY frame with error code NO_ERROR and Last-Stream-ID lower than the stream id corresponding to the request indicating that this request has not been processed yet, or a RST_STREAM frame with error code REFUSED_STREAM. Client MAY retry (on a different connection). See RFC7540 Section 8.1.4.
ArkWeb_NetError_ARKWEB_ERR_HTTP2_STREAM_CLOSED
@error Received an HTTP/2 frame on a closed stream.
ArkWeb_NetError_ARKWEB_ERR_HTTPS_PROXY_TUNNEL_RESPONSE_REDIRECT
@error A request to create an SSL tunnel connection through the HTTPS proxy received a 302 (temporary redirect, response. The response body might include a description of why the request failed.
ArkWeb_NetError_ARKWEB_ERR_HTTP_1_1_REQUIRED
@error HTTP_1_1_REQUIRED error code received on HTTP/2 session.
ArkWeb_NetError_ARKWEB_ERR_HTTP_RESPONSE_CODE_FAILURE
@error The server returned a non-2xx HTTP response code.
ArkWeb_NetError_ARKWEB_ERR_ICANN_NAME_COLLISION
@error Resolving a hostname to an IP address list included the IPv4 address “127.0.53.53”. This is a special IP address which ICANN has recommended to indicate there was a name collision, and alert admins to a potential problem.
ArkWeb_NetError_ARKWEB_ERR_IMPORT_CA_CERT_FAILED
@error CA import failed due to some other error.
ArkWeb_NetError_ARKWEB_ERR_IMPORT_CA_CERT_NOT_CA
@error CA import failed - not a CA cert.
ArkWeb_NetError_ARKWEB_ERR_IMPORT_CERT_ALREADY_EXISTS
@error Import failed - certificate already exists in database.
ArkWeb_NetError_ARKWEB_ERR_IMPORT_SERVER_CERT_FAILED
@error Server certificate import failed due to some internal error.
ArkWeb_NetError_ARKWEB_ERR_INCOMPLETE_CHUNKED_ENCODING
@error The HTTP response body is transferred with Chunked-Encoding, but the terminating zero-length chunk was never sent when the connection is closed.
ArkWeb_NetError_ARKWEB_ERR_INCOMPLETE_HTTP2_HEADERS
@error HTTP/2 headers have been received, but not all of them - status or version headers are missing, so we’re expecting additional frames to complete them.
ArkWeb_NetError_ARKWEB_ERR_INCONSISTENT_IP_ADDRESS_SPACE
@error The IP address space of the remote endpoint differed from the previous observed value during the same request. Any cache entry for the affected request should be invalidated.
ArkWeb_NetError_ARKWEB_ERR_INSECURE_RESPONSE
@error The server’s response was insecure (e.g. there was a cert error).
ArkWeb_NetError_ARKWEB_ERR_INSUFFICIENT_RESOURCES
@error There were not enough resources to complete the operation.
ArkWeb_NetError_ARKWEB_ERR_INTERNET_DISCONNECTED
@error The Internet connection has been lost.
ArkWeb_NetError_ARKWEB_ERR_INVALID_ARGUMENT
@error An argument to the function is incorrect.
ArkWeb_NetError_ARKWEB_ERR_INVALID_AUTH_CREDENTIALS
@error Credentials could not be established during HTTP Authentication.
ArkWeb_NetError_ARKWEB_ERR_INVALID_CHUNKED_ENCODING
@error Error in chunked transfer encoding.
ArkWeb_NetError_ARKWEB_ERR_INVALID_ECH_CONFIG_LIST
@error The ECHConfigList fetched over DNS cannot be parsed.
ArkWeb_NetError_ARKWEB_ERR_INVALID_HANDLE
@error The handle or file descriptor is invalid.
ArkWeb_NetError_ARKWEB_ERR_INVALID_HTTP_RESPONSE
@error The server was expected to return an HTTP/1.x response, but did not. Rather than treat it as HTTP/0.9, this error is returned.
ArkWeb_NetError_ARKWEB_ERR_INVALID_REDIRECT
@error Attempting to load an URL resulted in a redirect to an invalid URL.
ArkWeb_NetError_ARKWEB_ERR_INVALID_RESPONSE
@error The server’s response was invalid.
ArkWeb_NetError_ARKWEB_ERR_INVALID_SIGNED_EXCHANGE
@error An error occurred while handling a signed exchange.
ArkWeb_NetError_ARKWEB_ERR_INVALID_URL
@error The URL is invalid.
ArkWeb_NetError_ARKWEB_ERR_INVALID_WEB_BUNDLE
@error An error occurred while handling a Web Bundle source.
ArkWeb_NetError_ARKWEB_ERR_IO_PENDING
@error An asynchronous IO operation is not yet complete. This usually does not indicate a fatal error. Typically this error will be generated as a notification to wait for some external notification that the IO operation finally completed.
ArkWeb_NetError_ARKWEB_ERR_KEY_GENERATION_FAILED
@error Key generation failed.
ArkWeb_NetError_ARKWEB_ERR_MALFORMED_IDENTITY
@error The identity used for authentication is invalid.
ArkWeb_NetError_ARKWEB_ERR_MANDATORY_PROXY_CONFIGURATION_FAILED
@error A mandatory proxy configuration could not be used. Currently this means that a mandatory PAC script could not be fetched, parsed or executed.
ArkWeb_NetError_ARKWEB_ERR_METHOD_UNSUPPORTED
@error The server did not support the request method.
ArkWeb_NetError_ARKWEB_ERR_MISCONFIGURED_AUTH_ENVIRONMENT
@error The environment was not set up correctly for authentication (for example, no KDC could be found or the principal is unknown.
ArkWeb_NetError_ARKWEB_ERR_MISSING_AUTH_CREDENTIALS
@error (GSSAPI, No Kerberos credentials were available during HTTP Authentication.
ArkWeb_NetError_ARKWEB_ERR_MSG_TOO_BIG
@error The message was too large for the transport. (for example a UDP message which exceeds size threshold).
ArkWeb_NetError_ARKWEB_ERR_NAME_NOT_RESOLVED
@error The host name could not be resolved.
ArkWeb_NetError_ARKWEB_ERR_NAME_RESOLUTION_FAILED
@error An error occurred when trying to do a name resolution (DNS).
ArkWeb_NetError_ARKWEB_ERR_NETWORK_ACCESS_DENIED
@error Permission to access the network was denied. This is used to distinguish errors that were most likely caused by a firewall from other access denied errors. See also ERR_ACCESS_DENIED.
ArkWeb_NetError_ARKWEB_ERR_NETWORK_CHANGED
@error The network changed.
ArkWeb_NetError_ARKWEB_ERR_NETWORK_IO_SUSPENDED
@error An operation could not be completed because all network IO is suspended.
ArkWeb_NetError_ARKWEB_ERR_NOT_IMPLEMENTED
@error The operation failed because of unimplemented functionality.
ArkWeb_NetError_ARKWEB_ERR_NO_BUFFER_SPACE
@error No socket buffer space is available.
ArkWeb_NetError_ARKWEB_ERR_NO_PRIVATE_KEY_FOR_CERT
@error An attempt to import a client certificate failed, as the user’s key database lacked a corresponding private key.
ArkWeb_NetError_ARKWEB_ERR_NO_SSL_VERSIONS_ENABLED
@error No SSL protocol versions are enabled.
ArkWeb_NetError_ARKWEB_ERR_NO_SUPPORTED_PROXIES
@error There are no supported proxies in the provided list.
ArkWeb_NetError_ARKWEB_ERR_OUT_OF_MEMORY
@error Memory allocation failed.
ArkWeb_NetError_ARKWEB_ERR_PAC_NOT_IN_DHCP
@error No PAC URL configuration could be retrieved from DHCP. This can indicate either a failure to retrieve the DHCP configuration, or that there was no PAC URL configured in DHCP.
ArkWeb_NetError_ARKWEB_ERR_PAC_SCRIPT_FAILED
@error The evaluation of the PAC script failed.
ArkWeb_NetError_ARKWEB_ERR_PAC_SCRIPT_TERMINATED
@error The PAC script terminated fatally and must be reloaded.
ArkWeb_NetError_ARKWEB_ERR_PKCS12_IMPORT_BAD_PASSWORD
@error PKCS #12 import failed due to incorrect password.
ArkWeb_NetError_ARKWEB_ERR_PKCS12_IMPORT_FAILED
@error PKCS #12 import failed due to other error.
ArkWeb_NetError_ARKWEB_ERR_PKCS12_IMPORT_INVALID_FILE
@error PKCS #12 import failed due to invalid/corrupt file.
ArkWeb_NetError_ARKWEB_ERR_PKCS12_IMPORT_INVALID_MAC
@error PKCS #12 import failed due to invalid MAC.
ArkWeb_NetError_ARKWEB_ERR_PKCS12_IMPORT_UNSUPPORTED
@error PKCS #12 import failed due to unsupported features.
ArkWeb_NetError_ARKWEB_ERR_PRECONNECT_MAX_SOCKET_LIMIT
@error We’ve hit the max socket limit for the socket pool while preconnecting. We don’t bother trying to preconnect more sockets.
ArkWeb_NetError_ARKWEB_ERR_PRIVATE_KEY_EXPORT_FAILED
@error Failure to export private key.
ArkWeb_NetError_ARKWEB_ERR_PROXY_AUTH_REQUESTED
@error The proxy requested authentication (for tunnel establishment).
ArkWeb_NetError_ARKWEB_ERR_PROXY_AUTH_REQUESTED_WITH_NO_CONNECTION
@error Proxy Auth Requested without a valid Client Socket Handle.
ArkWeb_NetError_ARKWEB_ERR_PROXY_AUTH_UNSUPPORTED
@error The proxy requested authentication (for tunnel establishment, with an unsupported method.
ArkWeb_NetError_ARKWEB_ERR_PROXY_CERTIFICATE_INVALID
@error The certificate presented by the HTTPS Proxy was invalid.
ArkWeb_NetError_ARKWEB_ERR_PROXY_CONNECTION_FAILED
@error Could not create a connection to the proxy server. An error occurred either in resolving its name, or in connecting a socket to it. Note that this does NOT include failures during the actual “CONNECT” method of an HTTP proxy.
ArkWeb_NetError_ARKWEB_ERR_PROXY_HTTP_1_1_REQUIRED
@error HTTP_1_1_REQUIRED error code received on HTTP/2 session to proxy.
ArkWeb_NetError_ARKWEB_ERR_QUIC_GOAWAY_REQUEST_CAN_BE_RETRIED
@error A GOAWAY frame has been received indicating that the request has not been processed and is therefore safe to retry on a different connection.
ArkWeb_NetError_ARKWEB_ERR_QUIC_HANDSHAKE_FAILED
@error The QUIC crypto handshake failed. This means that the server was unable to read any requests sent, so they may be resent.
ArkWeb_NetError_ARKWEB_ERR_QUIC_PROTOCOL_ERROR
@error There is a QUIC protocol error.
ArkWeb_NetError_ARKWEB_ERR_QUIC_UNKNOWN_CERT_ROOT
@error The certificate presented on a QUIC connection does not chain to a known root and the origin connected to is not on a list of domains where unknown roots are allowed.
ArkWeb_NetError_ARKWEB_ERR_READ_IF_READY_NOT_IMPLEMENTED
@error Socket ReadIfReady support is not implemented. This error should not be user visible, because the normal Read(, method is used as a fallback.
ArkWeb_NetError_ARKWEB_ERR_REQUEST_RANGE_NOT_SATISFIABLE
@error The response was 416 (Requested range not satisfiable, and the server cannot satisfy the range requested.
ArkWeb_NetError_ARKWEB_ERR_RESPONSE_BODY_TOO_BIG_TO_DRAIN
@error The HTTP response was too big to drain.
ArkWeb_NetError_ARKWEB_ERR_RESPONSE_HEADERS_MULTIPLE_CONTENT_DISPOSITION
@error The HTTP response contained multiple Content-Disposition headers.
ArkWeb_NetError_ARKWEB_ERR_RESPONSE_HEADERS_MULTIPLE_CONTENT_LENGTH
@error The HTTP response contained multiple distinct Content-Length headers.
ArkWeb_NetError_ARKWEB_ERR_RESPONSE_HEADERS_MULTIPLE_LOCATION
@error The HTTP response contained multiple Location headers.
ArkWeb_NetError_ARKWEB_ERR_RESPONSE_HEADERS_TOO_BIG
@error The headers section of the response is too large.
ArkWeb_NetError_ARKWEB_ERR_RESPONSE_HEADERS_TRUNCATED
@error The HTTP headers were truncated by an EOF.
ArkWeb_NetError_ARKWEB_ERR_SELF_SIGNED_CERT_GENERATION_FAILED
@error Self-signed certificate generation failed.
ArkWeb_NetError_ARKWEB_ERR_SOCKET_CONNECTED
@error The socket is already connected.
ArkWeb_NetError_ARKWEB_ERR_SOCKET_NOT_CONNECTED
@error The socket is not connected.
ArkWeb_NetError_ARKWEB_ERR_SOCKET_RECEIVE_BUFFER_SIZE_UNCHANGEABLE
@error Failed to set the socket’s receive buffer size as requested, despite success return code from setsockopt.
ArkWeb_NetError_ARKWEB_ERR_SOCKET_SEND_BUFFER_SIZE_UNCHANGEABLE
@error Failed to set the socket’s send buffer size as requested, despite success return code from setsockopt.
ArkWeb_NetError_ARKWEB_ERR_SOCKET_SET_RECEIVE_BUFFER_SIZE_ERROR
@error Failed to set the socket’s receive buffer size as requested.
ArkWeb_NetError_ARKWEB_ERR_SOCKET_SET_SEND_BUFFER_SIZE_ERROR
@error Failed to set the socket’s send buffer size as requested.
ArkWeb_NetError_ARKWEB_ERR_SOCKS_CONNECTION_FAILED
@error Failed establishing a connection to the SOCKS proxy server for a target host.
ArkWeb_NetError_ARKWEB_ERR_SOCKS_CONNECTION_HOST_UNREACHABLE
@error The SOCKS proxy server failed establishing connection to the target host because that host is unreachable.
ArkWeb_NetError_ARKWEB_ERR_SSL_BAD_PEER_PUBLIC_KEY
@error SSL peer’s public key is invalid.
ArkWeb_NetError_ARKWEB_ERR_SSL_BAD_RECORD_MAC_ALERT
@error An SSL peer sent us a fatal bad_record_mac alert. This has been observed from servers with buggy DEFLATE support.
ArkWeb_NetError_ARKWEB_ERR_SSL_CLIENT_AUTH_CERT_BAD_FORMAT
@error Failed to import a client certificate from the platform store into the SSL library.
ArkWeb_NetError_ARKWEB_ERR_SSL_CLIENT_AUTH_CERT_NEEDED
@error The server requested a client certificate for SSL client authentication.
ArkWeb_NetError_ARKWEB_ERR_SSL_CLIENT_AUTH_CERT_NO_PRIVATE_KEY
@error The SSL client certificate has no private key.
ArkWeb_NetError_ARKWEB_ERR_SSL_CLIENT_AUTH_NO_COMMON_ALGORITHMS
@error There were no common signature algorithms between our client certificate private key and the server’s preferences.
ArkWeb_NetError_ARKWEB_ERR_SSL_CLIENT_AUTH_PRIVATE_KEY_ACCESS_DENIED
@error The permission to use the SSL client certificate’s private key was denied.
ArkWeb_NetError_ARKWEB_ERR_SSL_CLIENT_AUTH_SIGNATURE_FAILED
@error We were unable to sign the CertificateVerify data of an SSL client auth handshake with the client certificate’s private key. Possible causes for this include the user implicitly or explicitly denying access to the private key, the private key may not be valid for signing, the key may be relying on a cached handle which is no longer valid, or the CSP won’t allow arbitrary data to be signed.
ArkWeb_NetError_ARKWEB_ERR_SSL_DECOMPRESSION_FAILURE_ALERT
@error An SSL peer sent us a fatal decompression_failure alert. This typically occurs when a peer selects DEFLATE compression in the mistaken belief that it supports it.
ArkWeb_NetError_ARKWEB_ERR_SSL_DECRYPT_ERROR_ALERT
@error An SSL peer sent us a fatal decrypt_error alert. This typically occurs when a peer could not correctly verify a signature (in CertificateVerify or ServerKeyExchange, or validate a Finished message.
ArkWeb_NetError_ARKWEB_ERR_SSL_HANDSHAKE_NOT_COMPLETED
@error An operation failed because the SSL handshake has not completed.
ArkWeb_NetError_ARKWEB_ERR_SSL_KEY_USAGE_INCOMPATIBLE
@error The server’s certificate has a keyUsage extension incompatible with the negotiated TLS key exchange method.
ArkWeb_NetError_ARKWEB_ERR_SSL_NO_RENEGOTIATION
@error The peer sent an SSL no_renegotiation alert message.
ArkWeb_NetError_ARKWEB_ERR_SSL_OBSOLETE_CIPHER
@error The SSL server required an unsupported cipher suite that has since been removed. This error will temporarily be signaled on a fallback for one or two releases immediately following a cipher suite’s removal, after which the fallback will be removed.
ArkWeb_NetError_ARKWEB_ERR_SSL_OBSOLETE_VERSION_OR_CIPHER
@error The connection uses an obsolete version of SSL/TLS or cipher.
ArkWeb_NetError_ARKWEB_ERR_SSL_PINNED_KEY_NOT_IN_CERT_CHAIN
@error The certificate didn’t match the built-in public key pins for the host name. The pins are set in net/http/transport_security_state.cc and require that one of a set of public keys exist on the path from the leaf to the root.
ArkWeb_NetError_ARKWEB_ERR_SSL_PROTOCOL_ERROR
@error An SSL protocol error occurred.
ArkWeb_NetError_ARKWEB_ERR_SSL_RENEGOTIATION_REQUESTED
@error The server requested a renegotiation (rehandshake).
ArkWeb_NetError_ARKWEB_ERR_SSL_SERVER_CERT_BAD_FORMAT
@error The SSL server presented a certificate which could not be decoded. This is not a certificate error code as no X509Certificate object is available. This error is fatal.
ArkWeb_NetError_ARKWEB_ERR_SSL_SERVER_CERT_CHANGED
@error The SSL server certificate changed in a renegotiation.
ArkWeb_NetError_ARKWEB_ERR_SSL_UNRECOGNIZED_NAME_ALERT
@error The SSL server sent us a fatal unrecognized_name alert.
ArkWeb_NetError_ARKWEB_ERR_SSL_VERSION_OR_CIPHER_MISMATCH
@error The client and server don’t support a common SSL protocol version or cipher suite.
ArkWeb_NetError_ARKWEB_ERR_SYN_REPLY_NOT_RECEIVED
@error FLIP data received without receiving a SYN_REPLY on the stream.
ArkWeb_NetError_ARKWEB_ERR_TEMPORARILY_THROTTLED
@error The request throttler module cancelled this request to avoid DDOS.
ArkWeb_NetError_ARKWEB_ERR_TIMED_OUT
@error An operation timed out.
ArkWeb_NetError_ARKWEB_ERR_TLS13_DOWNGRADE_DETECTED
@error TLS 1.3 was enabled, but a lower version was negotiated and the server returned a value indicating it supported TLS 1.3. This is part of a security check in TLS 1.3, but it may also indicate the user is behind a buggy TLS-terminating proxy which implemented TLS 1.2 incorrectly. (See rhttps://crbug.com/boringssl/226.,
ArkWeb_NetError_ARKWEB_ERR_TOO_MANY_ACCEPT_CH_RESTARTS
@error The ACCEPT_CH restart has been triggered too many times.
ArkWeb_NetError_ARKWEB_ERR_TOO_MANY_REDIRECTS
@error Attempting to load an URL resulted in too many redirects.
ArkWeb_NetError_ARKWEB_ERR_TOO_MANY_RETRIES
@error An HTTP transaction was retried too many times due for authentication or invalid certificates.
ArkWeb_NetError_ARKWEB_ERR_TRUST_TOKEN_OPERATION_FAILED
@error A Trust Tokens protocol operation-executing request failed for one of a number of reasons (precondition failure, internal error, bad response).
ArkWeb_NetError_ARKWEB_ERR_TRUST_TOKEN_OPERATION_SUCCESS_WITHOUT_SENDING_REQUEST
@error When handling a Trust Tokens protocol operation-executing request, the system was able to execute the request’s Trust Tokens operation without sending the request to its destination.
ArkWeb_NetError_ARKWEB_ERR_TUNNEL_CONNECTION_FAILED
@error A tunnel connection through the proxy could not be established.
ArkWeb_NetError_ARKWEB_ERR_UNABLE_TO_REUSE_CONNECTION_FOR_PROXY_AUTH
@error The attempt to reuse a connection to send proxy auth credentials failed before the AuthController was used to generate credentials. The caller should reuse the controller with a new connection. This error is only used internally by the network stack.
ArkWeb_NetError_ARKWEB_ERR_UNDOCUMENTED_SECURITY_LIBRARY_STATUS
@error An undocumented SSPI or GSSAPI status code was returned.
ArkWeb_NetError_ARKWEB_ERR_UNEXPECTED
@error An unexpected error. This may be caused by a programming mistake or an invalid assumption.
ArkWeb_NetError_ARKWEB_ERR_UNEXPECTED_PROXY_AUTH
@error The response was 407 (Proxy Authentication Required,, yet we did not send the request to a proxy.
ArkWeb_NetError_ARKWEB_ERR_UNEXPECTED_SECURITY_LIBRARY_STATUS
@error An unexpected, but documented, SSPI or GSSAPI status code was returned.
ArkWeb_NetError_ARKWEB_ERR_UNKNOWN_URL_SCHEME
@error The scheme of the URL is unknown.
ArkWeb_NetError_ARKWEB_ERR_UNRECOGNIZED_FTP_DIRECTORY_LISTING_FORMAT
@error The server sent an FTP directory listing in a format we do not understand.
ArkWeb_NetError_ARKWEB_ERR_UNSAFE_PORT
@error Attempting to load an URL with an unsafe port number.
ArkWeb_NetError_ARKWEB_ERR_UNSAFE_REDIRECT
@error Attempting to load an URL resulted in an unsafe redirect (e.g., a redirect to file:// is considered unsafe).
ArkWeb_NetError_ARKWEB_ERR_UNSUPPORTED_AUTH_SCHEME
@error An HTTP Authentication scheme was tried which is not supported on this machine.
ArkWeb_NetError_ARKWEB_ERR_UPLOAD_FILE_CHANGED
@error The file upload failed because the file’s modification time was different from the expectation.
ArkWeb_NetError_ARKWEB_ERR_UPLOAD_STREAM_REWIND_NOT_SUPPORTED
@error The upload failed because the upload stream needed to be re-read, due to a retry or a redirect, but the upload stream doesn’t support that operation.
ArkWeb_NetError_ARKWEB_ERR_WINSOCK_UNEXPECTED_WRITTEN_BYTES
@error Winsock sometimes reports more data written than passed. This is probably due to a broken LSP.
ArkWeb_NetError_ARKWEB_ERR_WRONG_VERSION_ON_EARLY_DATA
@error TLS 1.3 early data was offered, but the server responded with TLS 1.2 or earlier. This is an internal error code to account for a backwards-compatibility issue with early data and TLS 1.2. It will be received before any data is returned from the socket. The request should be retried with early data disabled. See https://tools.ietf.org/html/rfc8446#appendix-D.3 for details.
ArkWeb_NetError_ARKWEB_ERR_WS_PROTOCOL_ERROR
@error Websocket protocol error. Indicates that we are terminating the connection due to a malformed frame or other protocol violation.
ArkWeb_NetError_ARKWEB_ERR_WS_THROTTLE_QUEUE_TOO_LARGE
@error There are too many pending WebSocketJob instances, so the new job was not pushed to the queue.
ArkWeb_NetError_ARKWEB_ERR_WS_UPGRADE
@error When a WebSocket handshake is done successfully and the connection has been upgraded, the URLRequest is cancelled with this error code.
ArkWeb_NetError_ARKWEB_NET_OK
@error Normal.
ArkWeb_ResourceType_CSP_REPORT
Report of Content Security Policy violations.
ArkWeb_ResourceType_FAVICON
Favicon.
ArkWeb_ResourceType_FONT_RESOURCE
Font.
ArkWeb_ResourceType_IMAGE
Image(jpg/gif/png/etc).
ArkWeb_ResourceType_MAIN_FRAME
Top level page.
ArkWeb_ResourceType_MEDIA
Media resource.
ArkWeb_ResourceType_NAVIGATION_PRELOAD_MAIN_FRAME
A main-frame service worker navigation preload request.
ArkWeb_ResourceType_NAVIGATION_PRELOAD_SUB_FRAME
A sub-frame service worker navigation preload request.
ArkWeb_ResourceType_OBJECT
Object (or embed) tag for a plugin, or a resource that a plugin requested.
ArkWeb_ResourceType_PING
Ping request for /sendBeacon.
ArkWeb_ResourceType_PLUGIN_RESOURCE
Resource that a plugin requested.
ArkWeb_ResourceType_PREFETCH
Explicitly requested prefetch.
ArkWeb_ResourceType_SCRIPT
External script.
ArkWeb_ResourceType_SERVICE_WORKER
The main resource of a service worker.
ArkWeb_ResourceType_SHARED_WORKER
Main resource of a shared worker.
ArkWeb_ResourceType_STYLE_SHEET
CSS stylesheet.
ArkWeb_ResourceType_SUB_FRAME
Frame or Iframe.
ArkWeb_ResourceType_SUB_RESOURCE
Some other subresource. This is the default type if the actual type is unknown.
ArkWeb_ResourceType_WORKER
Main resource of a dedicated worker.
ArkWeb_ResourceType_XHR
XMLHttpRequest.
ArkWeb_WebMessageType_ARKWEB_BUFFER
The data carried in the ArkWeb_WebMessage is buffer(uint8_t).
ArkWeb_WebMessageType_ARKWEB_NONE
Represent error data
ArkWeb_WebMessageType_ARKWEB_STRING
The data carried in the ArkWeb_WebMessage is string.

Functions

OH_ArkWebHttpBodyStream_GetPosition
@brief Get the current position of the data stream. @param httpBodyStream The ArkWeb_HttpBodyStream. @return The current position of data stream. 0 if httpBodyStream is invalid.
OH_ArkWebHttpBodyStream_GetSize
@brief Get the total size of the data stream.
OH_ArkWebHttpBodyStream_GetUserData
@brief Get the user data from ArkWeb_HttpBodyStream. @param httpBodyStream The ArkWeb_HttpBodyStream. @return The set user data.
OH_ArkWebHttpBodyStream_Init
@brief Init the http body stream.
OH_ArkWebHttpBodyStream_IsChunked
@brief Get if the data stream is chunked. @param httpBodyStream The ArkWeb_HttpBodyStream. @return True if is chunked; false otherwise.
OH_ArkWebHttpBodyStream_IsEof
@brief Returns true if all data has been consumed from this upload data stream.
OH_ArkWebHttpBodyStream_IsInMemory
@brief Returns true if the upload data in the stream is entirely in memory, and all read requests will succeed synchronously.
OH_ArkWebHttpBodyStream_Read
@brief Read the http body to the buffer.
OH_ArkWebHttpBodyStream_SetReadCallback
@brief Set the callback for OH_ArkWebHttpBodyStream_Read.
OH_ArkWebHttpBodyStream_SetUserData
@brief Set a user data to ArkWeb_HttpBodyStream. @param httpBodyStream The ArkWeb_HttpBodyStream. @param userData The user data to set. @return {@link ARKWEB_NET_OK} 0 - Success. {@link ARKWEB_INVALID_PARAM} 17100101 - Invalid param.
OH_ArkWebRequestHeaderList_Destroy
@brief Destroy the ArkWeb_RequestHeaderList. @param requestHeaderList The ArkWeb_RequestHeaderList to be destroyed.
OH_ArkWebRequestHeaderList_GetHeader
@brief Get the specified request header. @param requestHeaderList The list of request header. @param index The index of request header. @param key The header key. Caller must release the string by OH_ArkWeb_ReleaseString. @param value The header value. Caller must release the string by OH_ArkWeb_ReleaseString.
OH_ArkWebRequestHeaderList_GetSize
@brief Get the request headers size. @param requestHeaderList The list of request header. @return The size of request headers. -1 if requestHeaderList is invalid.
OH_ArkWebResourceHandler_Destroy
@brief Destroy the ArkWeb_ResourceHandler. @param resourceHandler The ArkWeb_ResourceHandler. @return {@link ARKWEB_NET_OK} 0 - Success. {@link ARKWEB_INVALID_PARAM} 17100101 - Invalid param.
OH_ArkWebResourceHandler_DidFailWithError
@brief Notify the ArkWeb that this request should be failed. @param resourceHandler The ArkWeb_ResourceHandler for the request. @param errorCode The error code for this request. Refer to arkweb_net_error_list.h. @return {@link ARKWEB_NET_OK} 0 - Success. {@link ARKWEB_INVALID_PARAM} 17100101 - Invalid param.
OH_ArkWebResourceHandler_DidFinish
@brief Notify the ArkWeb that this request should be finished and there is no more data available. @param resourceHandler The ArkWeb_ResourceHandler for the request. @return {@link ARKWEB_NET_OK} 0 - Success. {@link ARKWEB_INVALID_PARAM} 17100101 - Invalid param.
OH_ArkWebResourceHandler_DidReceiveData
@brief Pass response body data to intercepted requests. @param resourceHandler The ArkWeb_ResourceHandler for the request. @param buffer Buffer data to send. @param bufLen The size of buffer. @return {@link ARKWEB_NET_OK} 0 - Success. {@link ARKWEB_INVALID_PARAM} 17100101 - Invalid param.
OH_ArkWebResourceHandler_DidReceiveResponse
@brief Pass response headers to intercepted requests. @param resourceHandler The ArkWeb_ResourceHandler for the request. @param response The ArkWeb_Response for the intercepting requests. @return {@link ARKWEB_NET_OK} 0 - Success. {@link ARKWEB_INVALID_PARAM} 17100101 - Invalid param.
OH_ArkWebResourceRequest_Destroy
@brief Destroy the ArkWeb_ResourceRequest. @param resourceRequest The ArkWeb_ResourceRequest. @return {@link ARKWEB_NET_OK} 0 - Success. {@link ARKWEB_INVALID_PARAM} 17100101 - Invalid param.
OH_ArkWebResourceRequest_DestroyHttpBodyStream
@brief Destroy the http body stream. @param httpBodyStream The httpBodyStream to be destroyed.
OH_ArkWebResourceRequest_GetFrameUrl
@brief Get the url of frame which trigger this request. @param resourceRequest The ArkWeb_ResourceRequest. @param frameUrl The url of frame which trigger this request. This function will allocate memory for the url string and caller must release the string by OH_ArkWeb_ReleaseString.
OH_ArkWebResourceRequest_GetHttpBodyStream
@brief Create a ArkWeb_HttpBodyStream which used to read the http body. @param resourceRequest The ArkWeb_ResourceRequest. @param httpBodyStream The request’s http body. This function will allocate memory for the http body stream and caller must release the httpBodyStream by OH_ArkWebResourceRequest_DestroyHttpBodyStream.
OH_ArkWebResourceRequest_GetMethod
@brief Get the method of request. @param resourceRequest The ArkWeb_ResourceRequest. @param method The request’s http method. This function will allocate memory for the method string and caller must release the string by OH_ArkWeb_ReleaseString.
OH_ArkWebResourceRequest_GetReferrer
@brief Get the referrer of request. @param resourceRequest The ArkWeb_ResourceRequest. @param referrer The request’s referrer. This function will allocate memory for the post data string and caller must release the string by OH_ArkWeb_ReleaseString.
OH_ArkWebResourceRequest_GetRequestHeaders
@brief Get the OH_ArkWeb_RequestHeaderList of the request. @param resourceRequest The ArkWeb_ResourceRequest. @param requestHeaderList The RequestHeaderList of request.
OH_ArkWebResourceRequest_GetResourceType
@brief Get the resource type of request. @param resourceRequest The ArkWeb_ResourceRequest. @return The resource type of request. -1 if resourceRequest is invalid.
OH_ArkWebResourceRequest_GetUrl
@brief Get the url of request. @param resourceRequest The ArkWeb_ResourceRequest. @param url The request’s url. This function will allocate memory for the url string and caller must release the string by OH_ArkWeb_ReleaseString.
OH_ArkWebResourceRequest_GetUserData
@brief Get the user data from ArkWeb_ResourceRequest. @param resourceRequest The ArkWeb_ResourceRequest. @return The set user data.
OH_ArkWebResourceRequest_HasGesture
@brief Get if this is a request is triggered by user gesutre. @param resourceRequest The ArkWeb_ResourceRequest. @return True if this is triggered by user gesture; false otherwise.
OH_ArkWebResourceRequest_IsMainFrame
@brief Get if this is a request from main frame. @param resourceRequest The ArkWeb_ResourceRequest. @return True if this is from main frame; false otherwise.
OH_ArkWebResourceRequest_IsRedirect
@brief Get if this is a redirect request. @param resourceRequest The ArkWeb_ResourceRequest. @return True if this is a redirect; false otherwise.
OH_ArkWebResourceRequest_SetUserData
@brief Set a user data to ArkWeb_ResourceRequest. @param resourceRequest The ArkWeb_ResourceRequest. @param userData The user data to set. @return {@link ARKWEB_NET_OK} 0 - Success. {@link ARKWEB_INVALID_PARAM} 17100101 - Invalid param.
OH_ArkWebResponse_GetCharset
@brief Get the response’s charset. @param response The ArkWeb_Response. @param charset Return the response’s charset. This function will allocate memory for the charset string and caller must release the string by OH_ArkWeb_ReleaseString.
OH_ArkWebResponse_GetError
@brief Get the response’s error code. @param response The ArkWeb_Response. @return The response’s error code.
OH_ArkWebResponse_GetHeaderByName
@brief Get the header from the response. @param response The ArkWeb_Response. @param name The name of the header. @param value Return the header’s value. This function will allocate memory for the value string and caller must release the string by OH_ArkWeb_ReleaseString.
OH_ArkWebResponse_GetMimeType
@brief Get the response’s mime type. @param response The ArkWeb_Response. @param mimeType Return the response’s mime type. This function will allocate memory for the mime type string and caller must release the string by OH_ArkWeb_ReleaseString.
OH_ArkWebResponse_GetStatus
@brief Get the response’s status code. @param response The ArkWeb_Response. @return The response’s http status code. -1 if response is invalid.
OH_ArkWebResponse_GetStatusText
@brief Get the response’s status text. @param response The ArkWeb_Response. @param statusText Return the response’s statusText. This function will allocate memory for the statusText string and caller must release the string by OH_ArkWeb_ReleaseString.
OH_ArkWebResponse_GetUrl
@brief Get the resolved URL after redirects or changed as a result of HSTS. @param response The ArkWeb_Response. @param url The resolved URL.
OH_ArkWebResponse_SetCharset
@brief Set charset to ArkWeb_Response. @param response The ArkWeb_Response. @param charset The charset for the request. @return {@link ARKWEB_NET_OK} 0 - Success. {@link ARKWEB_INVALID_PARAM} 17100101 - Invalid param.
OH_ArkWebResponse_SetError
@brief Set a error code to ArkWeb_Response. @param response The ArkWeb_Response. @param errorCode The error code for the failed request. @return {@link ARKWEB_NET_OK} 0 - Success. {@link ARKWEB_INVALID_PARAM} 17100101 - Invalid param.
OH_ArkWebResponse_SetHeaderByName
@brief Set a header to ArkWeb_Response. @param response The ArkWeb_Response. @param name The name of the header. @param value The value of the header. @param overwirte If true will overwrite the exsits header, if false otherwise. @return {@link ARKWEB_NET_OK} 0 - Success. {@link ARKWEB_INVALID_PARAM} 17100101 - Invalid param.
OH_ArkWebResponse_SetMimeType
@brief Set mime type to ArkWebResponse. @param response The ArkWeb_Response. @param mimeType The mime type for the request. @return {@link ARKWEB_NET_OK} 0 - Success. {@link ARKWEB_INVALID_PARAM} 17100101 - Invalid param.
OH_ArkWebResponse_SetStatus
@brief Set a status code to ArkWebResponse. @param response The ArkWeb_Response. @param status The http status code for the request. @return {@link ARKWEB_NET_OK} 0 - Success. {@link ARKWEB_INVALID_PARAM} 17100101 - Invalid param.
OH_ArkWebResponse_SetStatusText
@brief Set a status text to ArkWebResponse. @param response The ArkWeb_Response. @param statusText The status text for the request. @return {@link ARKWEB_NET_OK} 0 - Success. {@link ARKWEB_INVALID_PARAM} 17100101 - Invalid param.
OH_ArkWebResponse_SetUrl
@brief Set the resolved URL after redirects or changed as a result of HSTS. @param response The ArkWeb_Response. @param url The resolved URL. @return {@link ARKWEB_NET_OK} 0 - Success. {@link ARKWEB_INVALID_PARAM} 17100101 - Invalid param.
OH_ArkWebSchemeHandler_GetUserData
@brief Get the user data from ArkWeb_SchemeHandler. @param schemeHandler The ArkWeb_SchemeHandler. @return The set user data.
OH_ArkWebSchemeHandler_SetOnRequestStart
@brief Set the OnRequestStart callback for SchemeHandler. @param schemeHandler The SchemeHandler for the scheme. @param onRequestStart The OnRequestStart callback. @return {@link ARKWEB_NET_OK} 0 - Success. {@link ARKWEB_INVALID_PARAM} 17100101 - Invalid param.
OH_ArkWebSchemeHandler_SetOnRequestStop
@brief Set the OnRequestStop callback for SchemeHandler. @param schemeHandler The SchemeHandler for the scheme. @param onRequestStop The OnRequestStop callback. @return {@link ARKWEB_NET_OK} 0 - Success. {@link ARKWEB_INVALID_PARAM} 17100101 - Invalid param.
OH_ArkWebSchemeHandler_SetUserData
@brief Set a user data to ArkWeb_SchemeHandler. @param schemeHandler The ArkWeb_SchemeHandler. @param userData The user data to set. @return {@link ARKWEB_NET_OK} 0 - Success. {@link ARKWEB_INVALID_PARAM} 17100101 - Invalid param.
OH_ArkWebServiceWorker_ClearSchemeHandlers
@brief Clear the handler registered on the specified web for service worker. @return {@link ARKWEB_NET_OK} 0 - Success.
OH_ArkWebServiceWorker_SetSchemeHandler
@brief Set a ArkWeb_SchemeHandler for a specific scheme to intercept requests of that scheme type.
OH_ArkWeb_ClearSchemeHandlers
@brief Clear the handler registered on the specified web. @param webTag The name of the web component. @return {@link ARKWEB_NET_OK} 0 - Success. {@link ARKWEB_INVALID_PARAM} 17100101 - Invalid param.
OH_ArkWeb_CreateResponse
@brief Create a Response for a request. @param response The created Response. Use OH_ArkWeb_DestroyResponse to destroy when donn’t need it.
OH_ArkWeb_CreateSchemeHandler
@brief Create a SchemeHandler. @param schemeHandler Return the created SchemeHandler. Use OH_ArkWeb_DestroySchemeHandler destroy it when donn’t need it.
OH_ArkWeb_DestroyResponse
@brief Destroy the Reponse. @param response The Response needs destroy.
OH_ArkWeb_DestroySchemeHandler
@brief Destroy a SchemeHandler. @param schemeHandler The ArkWeb_SchemeHandler to be destroy.
OH_ArkWeb_GetNativeAPI
@brief Obtains the native API set of a specified type. @param type Indicates the type of the native API set provided by ArkWeb. @return Return the pointer to the native API abstract object that carries the size. If the type is incorrect, a null pointer is returned.
OH_ArkWeb_RegisterCustomSchemes
@brief Register custom scheme to the ArkWeb.
OH_ArkWeb_ReleaseByteArray
@brief Release the byte array acquired by native function. @param byteArray The byte array to be released.
OH_ArkWeb_ReleaseString
@brief Release the string acquired by native function. @param string The string to be released.
OH_ArkWeb_SetSchemeHandler
@brief Set a ArkWeb_SchemeHandler for a specific scheme to intercept requests of that scheme type.
OH_NativeArkWeb_GetDestroyCallback
@brief Get the destroy callback.
OH_NativeArkWeb_GetJavaScriptProxyValidCallback
@brief Get the valid callback.
OH_NativeArkWeb_RegisterJavaScriptProxy
@brief Registers the JavaScript object and method list.
OH_NativeArkWeb_RunJavaScript
@brief Loads a piece of code and execute JS code in the context of the currently displayed page.
OH_NativeArkWeb_SetDestroyCallback
@brief Registers the destroy callback.
OH_NativeArkWeb_SetJavaScriptProxyValidCallback
@brief Registers the valid callback.
OH_NativeArkWeb_UnregisterJavaScriptProxy
@brief Deletes the registered object which th given name.

Type Aliases

ArkWeb_CustomSchemeOption
@brief Configuration information for custom schemes.
ArkWeb_ErrorCode
ArkWeb_HttpBodyStream
@brief The http body of the request.
ArkWeb_HttpBodyStreamInitCallback
@brief Callback when the init operation done. @param httpBodyStream The ArkWeb_HttpBodyStream. @param result {@link ARKWEB_NET_OK} on success otherwise refer to arkweb_net_error_list.h.
ArkWeb_HttpBodyStreamReadCallback
@brief Callback when the read operation done. @param httpBodyStream The ArkWeb_HttpBodyStream. @param buffer The buffer to receive data. @param bytesRead Callback after OH_ArkWebHttpBodyStream_Read. bytesRead greater than 0 means that the buffer is filled with data of bytesRead size. Caller can read from the buffer, and if OH_ArkWebHttpBodyStream_IsEOF is false, caller can continue to read the remaining data.
ArkWeb_NativeAPIVariantKind
@brief Defines the native API set type.
ArkWeb_NetError
ArkWeb_OnComponentCallback
@brief Defines the component callback of the native ArkWeb.
ArkWeb_OnJavaScriptCallback
@brief Defines the javascript callback of the native ArkWeb.
ArkWeb_OnJavaScriptProxyCallback
@brief Defines the javascript proxy callback of the native ArkWeb.
ArkWeb_OnMessageEventHandler
@brief Defines the callback to receive message from HTML.
ArkWeb_OnRequestStart
@brief Callback for handling the request.
ArkWeb_OnRequestStop
@brief Callback when the request is completed.
ArkWeb_RequestHeaderList
@brief The request headers of the request.
ArkWeb_ResourceHandler
@brief Used to intercept url requests.
ArkWeb_ResourceRequest
@brief The info of the request.
ArkWeb_ResourceType
@brief Resource type for a request.
ArkWeb_Response
@brief The response of the intercepted request.
ArkWeb_SchemeHandler
@brief This class is used to intercept requests for a specified scheme.
ArkWeb_WebMessagePortPtr
@brief Defines the ArkWeb_WebMessagePort that represent a HTML5 message port.
ArkWeb_WebMessagePtr
@brief Defines the ArkWeb_WebMessage.
ArkWeb_WebMessageType
@brief Defines the data type carried in a ArkWeb_WebMessage.
NativeArkWeb_OnDestroyCallback
@brief Defines the destroy callback of the web component.
NativeArkWeb_OnJavaScriptCallback
@brief Defines the javascript callback of the web component.
NativeArkWeb_OnJavaScriptProxyCallback
@brief Defines the javascript proxy callback of the web component.
NativeArkWeb_OnValidCallback
@brief Defines the valid callback of the web component.