OH_ArkWebHttpBodyStream_Read

Function OH_ArkWebHttpBodyStream_Read 

pub unsafe extern "C" fn OH_ArkWebHttpBodyStream_Read(
    httpBodyStream: *const ArkWeb_HttpBodyStream,
    buffer: *mut u8,
    bufLen: c_int,
)
@brief Read the http body to the buffer.

The buffer must be larger than the bufLen. We will be reading data from a worker thread to the buffer,\n so should not use the buffer in other threads before the callback to avoid concurrency issues.\n

@param httpBodyStream The ArkWeb_HttpBodyStream. @param buffer The buffer to receive data. @param bufLen The size of bytes to read.

@syscap SystemCapability.Web.Webview.Core @since 12