pub unsafe extern "C" fn OH_ArkWeb_SetSchemeHandler(
scheme: *const c_char,
webTag: *const c_char,
schemeHandler: *mut ArkWeb_SchemeHandler,
) -> boolExpand description
@brief Set a ArkWeb_SchemeHandler for a specific scheme to intercept requests of that scheme type.
SchemeHandler should be set after the BrowserContext created.\n Use WebviewController.initializeWebEngine to initialize the BrowserContext without create a ArkWeb.\n
@param scheme Scheme that need to be intercepted. @param webTag The name of the web component. @param schemeHandler The SchemeHandler for the scheme. Only requests triggered from the specified web will be notified through this handler. @return Return true if set SchemeHandler for specific scheme successful, return false otherwise.
@syscap SystemCapability.Web.Webview.Core @since 12