OH_NativeArkWeb_RunJavaScript

Function OH_NativeArkWeb_RunJavaScript 

pub unsafe extern "C" fn OH_NativeArkWeb_RunJavaScript(
    webTag: *const c_char,
    jsCode: *const c_char,
    callback: NativeArkWeb_OnJavaScriptCallback,
)
@brief Loads a piece of code and execute JS code in the context of the currently displayed page.

@param webTag The name of the web component. @param jsCode a piece of javascript code. @param callback Callbacks execute JavaScript script results.

@syscap SystemCapability.Web.Webview.Core @since 11