pub unsafe extern "C" fn OH_ArkWebHttpBodyStream_IsEof(
httpBodyStream: *const ArkWeb_HttpBodyStream,
) -> boolExpand description
@brief Returns true if all data has been consumed from this upload data stream.
For chunked uploads, returns false until the first read attempt.\n
@param httpBodyStream The ArkWeb_HttpBodyStream. @return True if all data has been consumed; false otherwise.
@syscap SystemCapability.Web.Webview.Core @since 12