pub unsafe extern "C" fn OH_ArkWebHttpBodyStream_IsInMemory(
httpBodyStream: *const ArkWeb_HttpBodyStream,
) -> boolExpand description
@brief Returns true if the upload data in the stream is entirely in memory, and all read requests will succeed synchronously.
Expected to return false for chunked requests.\n
@param httpBodyStream The ArkWeb_HttpBodyStream. @return True if the upload data is in memory; false otherwise.
@syscap SystemCapability.Web.Webview.Core @since 12