OH_ArkWebHttpBodyStream_SetReadCallback

Function OH_ArkWebHttpBodyStream_SetReadCallback 

pub unsafe extern "C" fn OH_ArkWebHttpBodyStream_SetReadCallback(
    httpBodyStream: *mut ArkWeb_HttpBodyStream,
    readCallback: ArkWeb_HttpBodyStreamReadCallback,
) -> i32
@brief Set the callback for OH_ArkWebHttpBodyStream_Read.

The result of OH_ArkWebHttpBodyStream_Read will be notified to caller through the readCallback.\n The callback will run in the same thread as OH_ArkWebHttpBodyStream_Read.\n

@param httpBodyStream The ArkWeb_HttpBodyStream. @param readCallback The callback of read function. @return {@link ARKWEB_NET_OK} 0 - Success. {@link ARKWEB_INVALID_PARAM} 17100101 - Invalid param.

@syscap SystemCapability.Web.Webview.Core @since 12