OH_ArkWeb_GetNativeAPI

Function OH_ArkWeb_GetNativeAPI 

pub unsafe extern "C" fn OH_ArkWeb_GetNativeAPI(
    type_: ArkWeb_NativeAPIVariantKind,
) -> *mut ArkWeb_AnyNativeAPI
@brief Obtains the native API set of a specified type. @param type Indicates the type of the native API set provided by ArkWeb. @return Return the pointer to the native API abstract object that carries the size. If the type is incorrect, a null pointer is returned.

@syscap SystemCapability.Web.Webview.Core @since 12