pub unsafe extern "C" fn OH_NativeArkWeb_GetJavaScriptProxyValidCallback(
webTag: *const c_char,
) -> NativeArkWeb_OnValidCallbackExpand description
@brief Get the valid callback.
@param webTag The name of the web component. @return Return the valid callback function registered. If the valid callback function specified by the parameter webTag is not set, a null pointer is returned.
@syscap SystemCapability.Web.Webview.Core @since 11