ArkWeb_CookieManagerAPI

Struct ArkWeb_CookieManagerAPI 

#[repr(C)]
pub struct ArkWeb_CookieManagerAPI { pub size: usize, pub fetchCookieSync: Option<unsafe extern "C" fn(url: *const c_char, incognito: bool, includeHttpOnly: bool, cookieValue: *mut *mut c_char) -> ArkWeb_ErrorCode>, pub configCookieSync: Option<unsafe extern "C" fn(url: *const c_char, cookieValue: *const c_char, incognito: bool, includeHttpOnly: bool) -> ArkWeb_ErrorCode>, pub existCookies: Option<unsafe extern "C" fn(incognito: bool) -> bool>, pub clearAllCookiesSync: Option<unsafe extern "C" fn(incognito: bool)>, pub clearSessionCookiesSync: Option<unsafe extern "C" fn()>, }
@brief Defines the native CookieManager API for ArkWeb. Before invoking an API, you are advised to use ARKWEB_MEMBER_MISSING to check whether the function structure has a corresponding function pointer to avoid crash caused by mismatch between the SDK and the device ROM. Use OH_ArkWeb_GetNativeAPI in the UI thread to obtain the CookieManager-related interface cluster.

@since 12

Fields

size: usize

The ArkWeb_CookieManagerAPI struct size.

fetchCookieSync: Option<unsafe extern "C" fn(url: *const c_char, incognito: bool, includeHttpOnly: bool, cookieValue: *mut *mut c_char) -> ArkWeb_ErrorCode>

@brief Obtains the cookie value corresponding to a specified URL.

@param url URL to which the cookie to be obtained belongs. A complete URL is recommended. @param incognito True indicates that the memory cookies of the webview in privacy mode are obtained, and false indicates that cookies in non-privacy mode are obtained. @param includeHttpOnly If true HTTP-only cookies will also be included in the cookieValue. @param cookieValue Get the cookie value corresponding to the URL. @return Fetch cookie result code. {@link ARKWEB_SUCCESS} fetch cookie success. {@link ARKWEB_INVALID_URL} invalid url. {@link ARKWEB_INVALID_PARAM} cookieValue is nullptr.

configCookieSync: Option<unsafe extern "C" fn(url: *const c_char, cookieValue: *const c_char, incognito: bool, includeHttpOnly: bool) -> ArkWeb_ErrorCode>

@brief Sets the cookie value for a specified URL.

@param url Specifies the URL to which the cookie belongs. A complete URL is recommended. @param cookieValue The value of the cookie to be set. @param incognito True indicates that cookies of the corresponding URL are set in privacy mode, and false indicates that cookies of the corresponding URL are set in non-privacy mode. @param includeHttpOnly If true, HTTP-only cookies can also be overwritten. @return Config cookie result code. {@link ARKWEB_SUCCESS} config cookie success. {@link ARKWEB_INVALID_URL} invalid url. {@link ARKWEB_INVALID_COOKIE_VALUE} invalid cookie value.

existCookies: Option<unsafe extern "C" fn(incognito: bool) -> bool>

@brief Check whether cookies exist.

@param incognito True indicates whether cookies exist in privacy mode, and false indicates whether cookies exist in non-privacy mode. @return True indicates that the cookie exists, and false indicates that the cookie does not exist.

clearAllCookiesSync: Option<unsafe extern "C" fn(incognito: bool)>

@brief Clear all cookies.

@param incognito True indicates that all memory cookies of the webview are cleared in privacy mode, and false indicates that persistent cookies in non-privacy mode are cleared.

clearSessionCookiesSync: Option<unsafe extern "C" fn()>

@brief Clear all session cookies.