#[repr(C)]pub struct ArkWeb_WebMessageAPI {
pub size: usize,
pub createWebMessage: Option<unsafe extern "C" fn() -> ArkWeb_WebMessagePtr>,
pub destroyWebMessage: Option<unsafe extern "C" fn(webMessage: *mut ArkWeb_WebMessagePtr)>,
pub setType: Option<unsafe extern "C" fn(webMessage: ArkWeb_WebMessagePtr, type_: ArkWeb_WebMessageType)>,
pub getType: Option<unsafe extern "C" fn(webMessage: ArkWeb_WebMessagePtr) -> ArkWeb_WebMessageType>,
pub setData: Option<unsafe extern "C" fn(webMessage: ArkWeb_WebMessagePtr, data: *mut c_void, dataLength: usize)>,
pub getData: Option<unsafe extern "C" fn(webMessage: ArkWeb_WebMessagePtr, dataLength: *mut usize) -> *mut c_void>,
}Expand description
@brief Defines the web message data API for native ArkWeb. Before invoking an API, you are advised to use ARKWEB_MEMBER_MISSING to check whether the function structure has a corresponding function pointer to avoid crash caused by mismatch between the SDK and the device ROM. Use OH_ArkWeb_GetNativeAPI in the UI thread to obtain the WebMessage-related interface cluster.
@since 12
Fields
size: usizeThe ArkWeb_WebMessageAPI struct size.
createWebMessage: Option<unsafe extern "C" fn() -> ArkWeb_WebMessagePtr>@brief Used to create a ArkWeb_WebMessage.
@return The created ArkWeb_WebMessage, destroy it through destroyWebMessage after it is no longer used.
destroyWebMessage: Option<unsafe extern "C" fn(webMessage: *mut ArkWeb_WebMessagePtr)>@brief Used to destroy a ArkWeb_WebMessage.
@param webMessage The ArkWeb_WebMessage to destroy.
setType: Option<unsafe extern "C" fn(webMessage: ArkWeb_WebMessagePtr, type_: ArkWeb_WebMessageType)>@brief Set the type of ArkWeb_WebMessage.
@param webMessage The ArkWeb_WebMessage. @param type The type of ArkWeb_WebMessage.
getType: Option<unsafe extern "C" fn(webMessage: ArkWeb_WebMessagePtr) -> ArkWeb_WebMessageType>@brief Get the type of ArkWeb_WebMessage.
@param webMessage The ArkWeb_WebMessage. @return The type of ArkWeb_WebMessage.
setData: Option<unsafe extern "C" fn(webMessage: ArkWeb_WebMessagePtr, data: *mut c_void, dataLength: usize)>@brief Set the data of ArkWeb_WebMessage.
@param webMessage The ArkWeb_WebMessage. @param data The data of ArkWeb_WebMessage. @param dataLength The length of data.
getData: Option<unsafe extern "C" fn(webMessage: ArkWeb_WebMessagePtr, dataLength: *mut usize) -> *mut c_void>@brief Get the data of ArkWeb_WebMessage.
@param webMessage The ArkWeb_WebMessage. @param dataLength The length of data. @return The data of ArkWeb_WebMessage.