#[repr(C)]pub struct ArkWeb_WebMessagePortAPI {
pub size: usize,
pub postMessage: Option<unsafe extern "C" fn(webMessagePort: ArkWeb_WebMessagePortPtr, webTag: *const c_char, webMessage: ArkWeb_WebMessagePtr) -> ArkWeb_ErrorCode>,
pub close: Option<unsafe extern "C" fn(webMessagePort: ArkWeb_WebMessagePortPtr, webTag: *const c_char)>,
pub setMessageEventHandler: Option<unsafe extern "C" fn(webMessagePort: ArkWeb_WebMessagePortPtr, webTag: *const c_char, messageEventHandler: ArkWeb_OnMessageEventHandler, userData: *mut c_void)>,
}Expand description
@brief Defines the web message API for native ArkWeb. Before invoking an API, you are advised to use ARKWEB_MEMBER_MISSING to check whether the function structure has a corresponding function pointer to avoid crash caused by mismatch between the SDK and the device ROM. Use OH_ArkWeb_GetNativeAPI in the UI thread to obtain the WebMessagePort-related interface cluster.
@since 12
Fields
size: usizeThe ArkWeb_WebMessagePortAPI struct size.
postMessage: Option<unsafe extern "C" fn(webMessagePort: ArkWeb_WebMessagePortPtr, webTag: *const c_char, webMessage: ArkWeb_WebMessagePtr) -> ArkWeb_ErrorCode>@brief Post message to HTML.
@param webMessagePort The ArkWeb_WebMessagePort. @param webTag The name of the web component. @param webMessage The ArkWeb_WebMessage to send. @return Post message result code. {@link ARKWEB_SUCCESS} post message success. {@link ARKWEB_INVALID_PARAM} the parameter verification fails. {@link ARKWEB_INIT_ERROR} no web associated with this webTag.
close: Option<unsafe extern "C" fn(webMessagePort: ArkWeb_WebMessagePortPtr, webTag: *const c_char)>@brief Close the message port.
@param webMessagePort The ArkWeb_WebMessagePort. @param webTag The name of the web component.
setMessageEventHandler: Option<unsafe extern "C" fn(webMessagePort: ArkWeb_WebMessagePortPtr, webTag: *const c_char, messageEventHandler: ArkWeb_OnMessageEventHandler, userData: *mut c_void)>@brief Set a callback to receive message from HTML.
@param webMessagePort The ArkWeb_WebMessagePort. @param webTag The name of the web component. @param messageEventHandler The handler to receive message from HTML. @param userData The data set by user.